@@ -290,7 +290,7 @@ if __name__ == "__main__":
         w_avg_csize = 20
         eps = 0
         random_norms = True
-        censor_rate = 0.05
+        censor_rate = 0.0
         generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
                                                       min_intra_corr=min_corr,
                                                       max_inter_corr=max_corr,
@@ -304,8 +304,8 @@ if __name__ == "__main__":
                   f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_rate}.csv"
         generated_M.to_csv(res_path / "random_nmf" / wh_name,
                            float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=2, ncmax=20)
-        pd.to_csv(res_path / f"{wh_name}_screeplot.csv")
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=6, ncmax=12)
+        df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
 
     if os.getenv("imp_do_ecodata_gans", "False").lower() == "true":
         # expérience où l'on soumet les résultats de l'imputation à un GAN
